summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--webkit/tools/layout_tests/layout_package/path_utils.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/webkit/tools/layout_tests/layout_package/path_utils.py b/webkit/tools/layout_tests/layout_package/path_utils.py
index 65160e4..5a4adf0 100644
--- a/webkit/tools/layout_tests/layout_package/path_utils.py
+++ b/webkit/tools/layout_tests/layout_package/path_utils.py
@@ -31,14 +31,14 @@ def WinPathToUnix(path):
return path.replace('\\', '/')
def WebKitRoot():
- """Returns the full path to the directory containing webkit.sln. Raises
- PathNotFound if we're unable to find webkit.sln."""
+ """Returns the full path to the directory containing webkit.gyp. Raises
+ PathNotFound if we're unable to find webkit.gyp."""
global _webkit_root
if _webkit_root:
return _webkit_root
- webkit_sln_path = google.path_utils.FindUpward(google.path_utils.ScriptDir(),
- 'webkit.sln')
- _webkit_root = os.path.dirname(webkit_sln_path)
+ webkit_gyp_path = google.path_utils.FindUpward(google.path_utils.ScriptDir(),
+ 'webkit.gyp')
+ _webkit_root = os.path.dirname(webkit_gyp_path)
return _webkit_root
def LayoutDataDir():
@@ -218,4 +218,4 @@ def PlatformDir():
return GetPlatformUtil().PlatformDir()
def PlatformNewResultsDir():
- return GetPlatformUtil().PlatformNewResultsDir() \ No newline at end of file
+ return GetPlatformUtil().PlatformNewResultsDir()